pub fn parse_planner_graph_output(text: &str) -> Option<PlannerGraphOutput>Expand description
Parse planner output as a DAG. Tries the new format first, converts legacy batch format into equivalent DAG nodes if needed.
pub fn parse_planner_graph_output(text: &str) -> Option<PlannerGraphOutput>Parse planner output as a DAG. Tries the new format first, converts legacy batch format into equivalent DAG nodes if needed.