pub struct Config {
pub project: ProjectConfig,
pub pipeline: PipelineConfig,
pub labels: LabelConfig,
pub multi_repo: MultiRepoConfig,
pub models: ModelConfig,
pub repos: HashMap<String, PathBuf>,
}Fields
project: ProjectConfigpipeline: PipelineConfiglabels: LabelConfigmulti_repo: MultiRepoConfigmodels: ModelConfigrepos: HashMap<String, PathBuf>Implementations
Sourceimpl Config
impl Config
Sourcepub fn load(project_dir: &Path) -> Result<Self>
pub fn load(project_dir: &Path) -> Result<Self>
Load config by merging user defaults with project overrides.
User config: ~/.config/oven/recipe.toml
Project config: recipe.toml in project_dir
Missing files are not errors - defaults are used instead.
Sourcepub fn resolve_repo(&self, name: &str) -> Result<PathBuf>
pub fn resolve_repo(&self, name: &str) -> Result<PathBuf>
Resolve a repo name to a local path.
Returns an error if the repo name is not in the config or the path doesn’t exist.
Sourcepub fn default_user_toml() -> String
pub fn default_user_toml() -> String
Generate a starter user TOML for ~/.config/oven/recipe.toml.
Sourcepub fn default_project_toml() -> String
pub fn default_project_toml() -> String
Generate a starter project TOML for oven prep.