RunStatus

Enum RunStatus 

pub enum RunStatus {
    Pending,
    Implementing,
    Reviewing,
    Fixing,
    AwaitingMerge,
    Merging,
    Complete,
    Failed,
}
Run status for pipeline runs.

Variants



Pending



Implementing



Reviewing



Fixing



AwaitingMerge



Merging



Complete



Failed

Implementations

Source

impl RunStatus

pub const fn next(self, has_findings: bool, cycle: u32) -> Self

Determine the next state in the pipeline based on review findings and cycle count.

  • After implementing, always review.
  • If reviewer finds issues and we haven’t hit max cycles, fix.
  • If reviewer finds issues at max cycles, move to awaiting merge (unresolved findings are posted on the PR for human review, not treated as failure).
  • Clean review goes to awaiting merge (waiting for PR to be merged).
  • After fixing, go back to reviewing.
  • After awaiting merge, proceed to merging.
  • After merging, complete.
pub const fn is_terminal(self) -> bool