Module graph

Module graph 

Structs

GraphNodeRow
A row from the graph_nodes table.

Enums

NodeState
State of a node in the dependency graph (stored as text in SQLite).

Functions

delete_session
get_active_session
Find a session that has at least one non-terminal node.
get_edges
get_nodes
insert_edge
insert_node
update_node_pr
update_node_run_id
update_node_state