pub fn get_active_session(conn: &Connection) -> Result<Option<String>>Expand description
Find a session that has at least one non-terminal node.
When multiple active sessions exist, the returned session is arbitrary. In practice there is at most one active session at a time.