commit_merge

Function commit_merge 

pub async fn commit_merge(repo_dir: &Path, conflicting: &[String]) -> Result<()>
Stage resolved conflict files and commit (used after agent conflict resolution).

Only stages files that git considers part of the merge (previously conflicting), rather than git add -A which could accidentally stage untracked files the agent left behind.