fetch_branch

Function fetch_branch 

pub async fn fetch_branch(repo_dir: &Path, branch: &str) -> Result<()>
Fetch a branch from origin to update the remote tracking ref.

Used between pipeline layers so that new worktrees (which branch from origin/<branch>) start from post-merge state.