Module github

Module github 

Modules

issues
labels
prs

Structs

GhClient
Client for GitHub operations via the gh CLI.
Issue
A GitHub issue.
IssueAuthor
The author of a GitHub issue (gh CLI returns {"login": "..."} objects).
IssueLabel
A label on a GitHub issue (gh CLI returns objects with a name field).

Enums

PrState
The merge state of a pull request.

Functions

safe_comment
Post a comment on a PR in a specific repo, logging errors instead of propagating them.
transition_issue
Transition an issue from one label to another in a single gh call.