pub struct ParsedIssue {
pub issue: Issue,
pub target_repo: Option<String>,
pub body_without_frontmatter: String,
}Expand description
An issue with parsed frontmatter metadata.
When multi-repo mode is enabled, issues can include YAML frontmatter at the top of the body to specify which target repo the work should go to.
Fields
issue: Issuetarget_repo: Option<String>body_without_frontmatter: StringTrait Implementations
Sourceimpl Clone for ParsedIssue
impl Clone for ParsedIssue
Sourcefn clone(&self) -> ParsedIssue
fn clone(&self) -> ParsedIssue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ParsedIssue
impl RefUnwindSafe for ParsedIssue
impl Send for ParsedIssue
impl Sync for ParsedIssue
impl Unpin for ParsedIssue
impl UnsafeUnpin for ParsedIssue
impl UnwindSafe for ParsedIssue