run_with_retry

Function run_with_retry 

pub async fn run_with_retry<R: CommandRunner>(
    runner: &R,
    invocation: &AgentInvocation,
) -> Result<AgentResult>
Invoke an agent with retry logic for transient failures.

Retries up to MAX_RETRIES times (with backoff) when the error message matches known transient patterns (connection resets, rate limits, 5xx, etc.).