Modules
Structs
- GhClient
- Client for GitHub operations via the
ghCLI. - Issue
- A GitHub issue.
- Issue
Label - A label on a GitHub issue (gh CLI returns objects with a
namefield).
Functions
- safe_
comment - Post a comment, logging errors instead of propagating them.
- transition_
issue - Transition an issue from one label to another in a single gh call.