pub struct PipelineExecutor<R: CommandRunner> {
pub runner: Arc<R>,
pub github: Arc<GhClient<R>>,
pub issues: Arc<dyn IssueProvider>,
pub db: Arc<Mutex<Connection>>,
pub config: Config,
pub cancel_token: CancellationToken,
pub repo_dir: PathBuf,
}Expand description
Runs a single issue through the full pipeline.
Fields
runner: Arc<R>github: Arc<GhClient<R>>issues: Arc<dyn IssueProvider>db: Arc<Mutex<Connection>>config: Configcancel_token: CancellationTokenrepo_dir: PathBufImplementations
Sourceimpl<R: CommandRunner + 'static> PipelineExecutor<R>
impl<R: CommandRunner + 'static> PipelineExecutor<R>
Sourcepub async fn run_issue(
&self,
issue: &PipelineIssue,
auto_merge: bool,
) -> Result<()>
pub async fn run_issue( &self, issue: &PipelineIssue, auto_merge: bool, ) -> Result<()>
Run the full pipeline for a single issue.
Sourcepub async fn run_issue_with_complexity(
&self,
issue: &PipelineIssue,
auto_merge: bool,
complexity: Option<Complexity>,
) -> Result<()>
pub async fn run_issue_with_complexity( &self, issue: &PipelineIssue, auto_merge: bool, complexity: Option<Complexity>, ) -> Result<()>
Run the full pipeline for a single issue with an optional complexity classification.
Sourcepub async fn plan_issues(
&self,
issues: &[PipelineIssue],
) -> Option<PlannerOutput>
pub async fn plan_issues( &self, issues: &[PipelineIssue], ) -> Option<PlannerOutput>
Invoke the planner agent to decide batching and complexity for a set of issues.
Returns None if the planner fails or returns unparseable output (fallback to default).